@@ -9,7 +9,7 @@ from scipy.fft._pocketfft import (ifft, fft, fftn, ifftn,
                                   rfft, irfft, rfftn, irfftn, fft2,
                                   hfft, ihfft, hfftn, ihfftn)
 
-from numpy import (arange, add, array, asarray, zeros, dot, exp, pi,
+from numpy import (arange, array, asarray, zeros, dot, exp, pi,
                    swapaxes, cdouble)
 import numpy as np
 import numpy.fft
@@ -37,7 +37,7 @@ SMALL_PRIME_SIZES = [
 
 def _assert_close_in_norm(x, y, rtol, size, rdt):
     # helper function for testing
-    err_msg = "size: %s  rdt: %s" % (size, rdt)
+    err_msg = f"size: {size}  rdt: {rdt}"
     assert_array_less(np.linalg.norm(x - y), rtol*np.linalg.norm(x), err_msg)
 
 
@@ -49,12 +49,6 @@ def swap_byteorder(arr):
     dtype = arr.dtype.newbyteorder('S')
     return arr.astype(dtype)
 
-def get_mat(n):
-    data = arange(n)
-    data = add.outer(data, data)
-    return data
-
-
 def direct_dft(x):
     x = asarray(x)
     n = len(x)
@@ -77,14 +71,14 @@ def direct_idft(x):
 
 def direct_dftn(x):
     x = asarray(x)
-    for axis in range(len(x.shape)):
+    for axis in range(x.ndim):
         x = fft(x, axis=axis)
     return x
 
 
 def direct_idftn(x):
     x = asarray(x)
-    for axis in range(len(x.shape)):
+    for axis in range(x.ndim):
         x = ifft(x, axis=axis)
     return x
 
@@ -339,9 +333,9 @@ class _TestRFFTBase:
             try:
                 return getattr(self.data, item)
             except AttributeError as e:
-                raise AttributeError(("'MockSeries' object "
+                raise AttributeError("'MockSeries' object "
                                       "has no attribute '{attr}'".
-                                      format(attr=item))) from e
+                                      format(attr=item)) from e
 
     def test_non_ndarray_with_dtype(self):
         x = np.array([1., 2., 3., 4., 5.])
@@ -887,7 +881,7 @@ class TestOverwrite:
         for fake in [lambda x: x, FakeArray, FakeArray2]:
             routine(fake(x2), fftsize, axis, overwrite_x=overwrite_x)
 
-            sig = "%s(%s%r, %r, axis=%r, overwrite_x=%r)" % (
+            sig = "{}({}{!r}, {!r}, axis={!r}, overwrite_x={!r})".format(
                 routine.__name__, x.dtype, x.shape, fftsize, axis, overwrite_x)
             if not should_overwrite:
                 assert_equal(x2, x, err_msg="spurious overwrite in %s" % sig)
