@@ -67,6 +67,12 @@ class TestUnivariateSpline:
         spl = UnivariateSpline(x, y, k=3)
         assert_almost_equal(spl.roots()[0], 1.050290639101332)
 
+    def test_roots_length(self): # for gh18335
+        x = np.linspace(0, 50 * np.pi, 1000)
+        y = np.cos(x)
+        spl = UnivariateSpline(x, y, s=0)
+        assert_equal(len(spl.roots()), 50)
+
     def test_derivatives(self):
         x = [1, 3, 5, 7, 9]
         y = [0, 4, 9, 12, 21]
@@ -786,7 +792,7 @@ class TestLSQSphereBivariateSpline:
         # define knots and extract data values at the knots
         knotst = theta[::5]
         knotsp = phi[::5]
-        w = ones((lats.ravel().shape[0]))
+        w = ones(lats.ravel().shape[0])
 
         # np.array input
         spl1 = LSQSphereBivariateSpline(lats.ravel(), lons.ravel(),
@@ -1294,7 +1300,7 @@ def _numdiff_2d(func, x, y, dx=0, dy=0, eps=1e-8):
         raise ValueError("invalid derivative order")
 
 
-class Test_DerivedBivariateSpline(object):
+class Test_DerivedBivariateSpline:
     """Test the creation, usage, and attribute access of the (private)
     _DerivedBivariateSpline class.
     """
