@@ -1,4 +1,3 @@
-
 def configuration(parent_package='',top_path=None):
     from numpy.distutils.misc_util import Configuration
     config = Configuration('io', parent_package, top_path)
@@ -9,7 +8,7 @@ def configuration(parent_package='',top_path=None):
     config.add_data_dir('tests')
     config.add_subpackage('matlab')
     config.add_subpackage('arff')
-    config.add_subpackage('harwell_boeing')
+    config.add_subpackage('_harwell_boeing')
     return config
 
 
