@@ -733,7 +733,7 @@ def solve_discrete_are(a, b, q, r, e=None, s=None, balanced=True):
     sym_threshold = np.max([np.spacing(1000.), 0.1*n_u_sym])
 
     if norm(u_sym, 1) > sym_threshold:
-        raise LinAlgError('The associated symplectic pencil has eigenvalues'
+        raise LinAlgError('The associated symplectic pencil has eigenvalues '
                           'too close to the unit circle')
 
     return (x + x.conj().T)/2
@@ -778,7 +778,7 @@ def _are_validate_args(a, b, q, r, e, s, eq_type='care'):
 
     """
 
-    if not eq_type.lower() in ('dare', 'care'):
+    if eq_type.lower() not in ("dare", "care"):
         raise ValueError("Equation type unknown. "
                          "Only 'care' and 'dare' is understood")
 
