@@ -163,7 +163,7 @@ We can also do this explicitly via:
 >>> n = 1000
 >>> A = np.empty((n, n), order='F')
 >>> for j in range(n):
->>>     for i in range(m):
+>>>     for i in range(n):
 >>>         A[i,j] = 1. / (i + j + 1)
 
 Note the use of the flag ``order='F'`` in :func:`numpy.empty`. This
@@ -382,10 +382,24 @@ backend routine.
 
 """
 
-import scipy.linalg._interpolative_backend as backend
+import scipy.linalg._interpolative_backend as _backend
 import numpy as np
 import sys
 
+__all__ = [
+    'estimate_rank',
+    'estimate_spectral_norm',
+    'estimate_spectral_norm_diff',
+    'id_to_svd',
+    'interp_decomp',
+    'rand',
+    'reconstruct_interp_matrix',
+    'reconstruct_matrix_from_id',
+    'reconstruct_skel_matrix',
+    'seed',
+    'svd',
+]
+
 _DTYPE_ERROR = ValueError("invalid input dtype (input must be float64 or complex128)")
 _TYPE_ERROR = TypeError("invalid input type (must be array or LinearOperator)")
 _32BIT_ERROR = ValueError("interpolative decomposition on 32-bit systems "
@@ -428,23 +442,23 @@ def seed(seed=None):
         initialize the generator.
 
     """
-    # For details, see :func:`backend.id_srand`, :func:`backend.id_srandi`,
-    # and :func:`backend.id_srando`.
+    # For details, see :func:`_backend.id_srand`, :func:`_backend.id_srandi`,
+    # and :func:`_backend.id_srando`.
 
     if isinstance(seed, str) and seed == 'default':
-        backend.id_srando()
+        _backend.id_srando()
     elif hasattr(seed, '__len__'):
         state = np.asfortranarray(seed, dtype=float)
         if state.shape != (55,):
             raise ValueError("invalid input size")
         elif state.min() < 0 or state.max() > 1:
             raise ValueError("values not in range [0,1]")
-        backend.id_srandi(state)
+        _backend.id_srandi(state)
     elif seed is None:
-        backend.id_srandi(np.random.rand(55))
+        _backend.id_srandi(np.random.rand(55))
     else:
         rnd = np.random.RandomState(seed)
-        backend.id_srandi(rnd.rand(55))
+        _backend.id_srandi(rnd.rand(55))
 
 
 def rand(*shape):
@@ -457,12 +471,12 @@ def rand(*shape):
 
     Parameters
     ----------
-    shape
+    *shape
         Shape of output array
 
     """
-    # For details, see :func:`backend.id_srand`, and :func:`backend.id_srando`.
-    return backend.id_srand(np.prod(shape)).reshape(shape)
+    # For details, see :func:`_backend.id_srand`, and :func:`_backend.id_srando`.
+    return _backend.id_srand(np.prod(shape)).reshape(shape)
 
 
 def interp_decomp(A, eps_or_k, rand=True):
@@ -511,12 +525,12 @@ def interp_decomp(A, eps_or_k, rand=True):
 
     ..  This function automatically detects the form of the input parameters
         and passes them to the appropriate backend. For details, see
-        :func:`backend.iddp_id`, :func:`backend.iddp_aid`,
-        :func:`backend.iddp_rid`, :func:`backend.iddr_id`,
-        :func:`backend.iddr_aid`, :func:`backend.iddr_rid`,
-        :func:`backend.idzp_id`, :func:`backend.idzp_aid`,
-        :func:`backend.idzp_rid`, :func:`backend.idzr_id`,
-        :func:`backend.idzr_aid`, and :func:`backend.idzr_rid`.
+        :func:`_backend.iddp_id`, :func:`_backend.iddp_aid`,
+        :func:`_backend.iddp_rid`, :func:`_backend.iddr_id`,
+        :func:`_backend.iddr_aid`, :func:`_backend.iddr_rid`,
+        :func:`_backend.idzp_id`, :func:`_backend.idzp_aid`,
+        :func:`_backend.idzp_rid`, :func:`_backend.idzr_id`,
+        :func:`_backend.idzr_aid`, and :func:`_backend.idzr_rid`.
 
     Parameters
     ----------
@@ -549,31 +563,31 @@ def interp_decomp(A, eps_or_k, rand=True):
             eps = eps_or_k
             if rand:
                 if real:
-                    k, idx, proj = backend.iddp_aid(eps, A)
+                    k, idx, proj = _backend.iddp_aid(eps, A)
                 else:
                     if _IS_32BIT:
                         raise _32BIT_ERROR
-                    k, idx, proj = backend.idzp_aid(eps, A)
+                    k, idx, proj = _backend.idzp_aid(eps, A)
             else:
                 if real:
-                    k, idx, proj = backend.iddp_id(eps, A)
+                    k, idx, proj = _backend.iddp_id(eps, A)
                 else:
-                    k, idx, proj = backend.idzp_id(eps, A)
+                    k, idx, proj = _backend.idzp_id(eps, A)
             return k, idx - 1, proj
         else:
             k = int(eps_or_k)
             if rand:
                 if real:
-                    idx, proj = backend.iddr_aid(A, k)
+                    idx, proj = _backend.iddr_aid(A, k)
                 else:
                     if _IS_32BIT:
                         raise _32BIT_ERROR
-                    idx, proj = backend.idzr_aid(A, k)
+                    idx, proj = _backend.idzr_aid(A, k)
             else:
                 if real:
-                    idx, proj = backend.iddr_id(A, k)
+                    idx, proj = _backend.iddr_id(A, k)
                 else:
-                    idx, proj = backend.idzr_id(A, k)
+                    idx, proj = _backend.idzr_id(A, k)
             return idx - 1, proj
     elif isinstance(A, LinearOperator):
         m, n = A.shape
@@ -581,20 +595,20 @@ def interp_decomp(A, eps_or_k, rand=True):
         if eps_or_k < 1:
             eps = eps_or_k
             if real:
-                k, idx, proj = backend.iddp_rid(eps, m, n, matveca)
+                k, idx, proj = _backend.iddp_rid(eps, m, n, matveca)
             else:
                 if _IS_32BIT:
                     raise _32BIT_ERROR
-                k, idx, proj = backend.idzp_rid(eps, m, n, matveca)
+                k, idx, proj = _backend.idzp_rid(eps, m, n, matveca)
             return k, idx - 1, proj
         else:
             k = int(eps_or_k)
             if real:
-                idx, proj = backend.iddr_rid(m, n, matveca, k)
+                idx, proj = _backend.iddr_rid(m, n, matveca, k)
             else:
                 if _IS_32BIT:
                     raise _32BIT_ERROR
-                idx, proj = backend.idzr_rid(m, n, matveca, k)
+                idx, proj = _backend.idzr_rid(m, n, matveca, k)
             return idx - 1, proj
     else:
         raise _TYPE_ERROR
@@ -613,8 +627,8 @@ def reconstruct_matrix_from_id(B, idx, proj):
     :func:`reconstruct_skel_matrix`.
 
     ..  This function automatically detects the matrix data type and calls the
-        appropriate backend. For details, see :func:`backend.idd_reconid` and
-        :func:`backend.idz_reconid`.
+        appropriate backend. For details, see :func:`_backend.idd_reconid` and
+        :func:`_backend.idz_reconid`.
 
     Parameters
     ----------
@@ -631,9 +645,9 @@ def reconstruct_matrix_from_id(B, idx, proj):
         Reconstructed matrix.
     """
     if _is_real(B):
-        return backend.idd_reconid(B, idx + 1, proj)
+        return _backend.idd_reconid(B, idx + 1, proj)
     else:
-        return backend.idz_reconid(B, idx + 1, proj)
+        return _backend.idz_reconid(B, idx + 1, proj)
 
 
 def reconstruct_interp_matrix(idx, proj):
@@ -654,8 +668,8 @@ def reconstruct_interp_matrix(idx, proj):
     :func:`reconstruct_skel_matrix`.
 
     ..  This function automatically detects the matrix data type and calls the
-        appropriate backend. For details, see :func:`backend.idd_reconint` and
-        :func:`backend.idz_reconint`.
+        appropriate backend. For details, see :func:`_backend.idd_reconint` and
+        :func:`_backend.idz_reconint`.
 
     Parameters
     ----------
@@ -670,9 +684,9 @@ def reconstruct_interp_matrix(idx, proj):
         Interpolation matrix.
     """
     if _is_real(proj):
-        return backend.idd_reconint(idx + 1, proj)
+        return _backend.idd_reconint(idx + 1, proj)
     else:
-        return backend.idz_reconint(idx + 1, proj)
+        return _backend.idz_reconint(idx + 1, proj)
 
 
 def reconstruct_skel_matrix(A, k, idx):
@@ -692,8 +706,8 @@ def reconstruct_skel_matrix(A, k, idx):
     :func:`reconstruct_interp_matrix`.
 
     ..  This function automatically detects the matrix data type and calls the
-        appropriate backend. For details, see :func:`backend.idd_copycols` and
-        :func:`backend.idz_copycols`.
+        appropriate backend. For details, see :func:`_backend.idd_copycols` and
+        :func:`_backend.idz_copycols`.
 
     Parameters
     ----------
@@ -710,9 +724,9 @@ def reconstruct_skel_matrix(A, k, idx):
         Skeleton matrix.
     """
     if _is_real(A):
-        return backend.idd_copycols(A, k, idx + 1)
+        return _backend.idd_copycols(A, k, idx + 1)
     else:
-        return backend.idz_copycols(A, k, idx + 1)
+        return _backend.idz_copycols(A, k, idx + 1)
 
 
 def id_to_svd(B, idx, proj):
@@ -728,8 +742,8 @@ def id_to_svd(B, idx, proj):
     See also :func:`svd`.
 
     ..  This function automatically detects the matrix data type and calls the
-        appropriate backend. For details, see :func:`backend.idd_id2svd` and
-        :func:`backend.idz_id2svd`.
+        appropriate backend. For details, see :func:`_backend.idd_id2svd` and
+        :func:`_backend.idz_id2svd`.
 
     Parameters
     ----------
@@ -750,9 +764,9 @@ def id_to_svd(B, idx, proj):
         Right singular vectors.
     """
     if _is_real(B):
-        U, V, S = backend.idd_id2svd(B, idx + 1, proj)
+        U, V, S = _backend.idd_id2svd(B, idx + 1, proj)
     else:
-        U, V, S = backend.idz_id2svd(B, idx + 1, proj)
+        U, V, S = _backend.idz_id2svd(B, idx + 1, proj)
     return U, S, V
 
 
@@ -761,8 +775,8 @@ def estimate_spectral_norm(A, its=20):
     Estimate spectral norm of a matrix by the randomized power method.
 
     ..  This function automatically detects the matrix data type and calls the
-        appropriate backend. For details, see :func:`backend.idd_snorm` and
-        :func:`backend.idz_snorm`.
+        appropriate backend. For details, see :func:`_backend.idd_snorm` and
+        :func:`_backend.idz_snorm`.
 
     Parameters
     ----------
@@ -780,12 +794,14 @@ def estimate_spectral_norm(A, its=20):
     from scipy.sparse.linalg import aslinearoperator
     A = aslinearoperator(A)
     m, n = A.shape
-    matvec = lambda x: A. matvec(x)
-    matveca = lambda x: A.rmatvec(x)
+    def matvec(x):
+        return A.matvec(x)
+    def matveca(x):
+        return A.rmatvec(x)
     if _is_real(A):
-        return backend.idd_snorm(m, n, matveca, matvec, its=its)
+        return _backend.idd_snorm(m, n, matveca, matvec, its=its)
     else:
-        return backend.idz_snorm(m, n, matveca, matvec, its=its)
+        return _backend.idz_snorm(m, n, matveca, matvec, its=its)
 
 
 def estimate_spectral_norm_diff(A, B, its=20):
@@ -794,8 +810,8 @@ def estimate_spectral_norm_diff(A, B, its=20):
     power method.
 
     ..  This function automatically detects the matrix data type and calls the
-        appropriate backend. For details, see :func:`backend.idd_diffsnorm` and
-        :func:`backend.idz_diffsnorm`.
+        appropriate backend. For details, see :func:`_backend.idd_diffsnorm` and
+        :func:`_backend.idz_diffsnorm`.
 
     Parameters
     ----------
@@ -817,15 +833,19 @@ def estimate_spectral_norm_diff(A, B, its=20):
     A = aslinearoperator(A)
     B = aslinearoperator(B)
     m, n = A.shape
-    matvec1 = lambda x: A. matvec(x)
-    matveca1 = lambda x: A.rmatvec(x)
-    matvec2 = lambda x: B. matvec(x)
-    matveca2 = lambda x: B.rmatvec(x)
+    def matvec1(x):
+        return A.matvec(x)
+    def matveca1(x):
+        return A.rmatvec(x)
+    def matvec2(x):
+        return B.matvec(x)
+    def matveca2(x):
+        return B.rmatvec(x)
     if _is_real(A):
-        return backend.idd_diffsnorm(
+        return _backend.idd_diffsnorm(
             m, n, matveca1, matveca2, matvec1, matvec2, its=its)
     else:
-        return backend.idz_diffsnorm(
+        return _backend.idz_diffsnorm(
             m, n, matveca1, matveca2, matvec1, matvec2, its=its)
 
 
@@ -846,12 +866,12 @@ def svd(A, eps_or_k, rand=True):
 
     ..  This function automatically detects the form of the input parameters and
         passes them to the appropriate backend. For details, see
-        :func:`backend.iddp_svd`, :func:`backend.iddp_asvd`,
-        :func:`backend.iddp_rsvd`, :func:`backend.iddr_svd`,
-        :func:`backend.iddr_asvd`, :func:`backend.iddr_rsvd`,
-        :func:`backend.idzp_svd`, :func:`backend.idzp_asvd`,
-        :func:`backend.idzp_rsvd`, :func:`backend.idzr_svd`,
-        :func:`backend.idzr_asvd`, and :func:`backend.idzr_rsvd`.
+        :func:`_backend.iddp_svd`, :func:`_backend.iddp_asvd`,
+        :func:`_backend.iddp_rsvd`, :func:`_backend.iddr_svd`,
+        :func:`_backend.iddr_asvd`, :func:`_backend.iddr_rsvd`,
+        :func:`_backend.idzp_svd`, :func:`_backend.idzp_asvd`,
+        :func:`_backend.idzp_rsvd`, :func:`_backend.idzr_svd`,
+        :func:`_backend.idzr_asvd`, and :func:`_backend.idzr_rsvd`.
 
     Parameters
     ----------
@@ -885,53 +905,55 @@ def svd(A, eps_or_k, rand=True):
             eps = eps_or_k
             if rand:
                 if real:
-                    U, V, S = backend.iddp_asvd(eps, A)
+                    U, V, S = _backend.iddp_asvd(eps, A)
                 else:
                     if _IS_32BIT:
                         raise _32BIT_ERROR
-                    U, V, S = backend.idzp_asvd(eps, A)
+                    U, V, S = _backend.idzp_asvd(eps, A)
             else:
                 if real:
-                    U, V, S = backend.iddp_svd(eps, A)
+                    U, V, S = _backend.iddp_svd(eps, A)
                 else:
-                    U, V, S = backend.idzp_svd(eps, A)
+                    U, V, S = _backend.idzp_svd(eps, A)
         else:
             k = int(eps_or_k)
             if k > min(A.shape):
-                raise ValueError("Approximation rank %s exceeds min(A.shape) = "
-                                 " %s " % (k, min(A.shape)))
+                raise ValueError("Approximation rank {} exceeds min(A.shape) = "
+                                 " {} ".format(k, min(A.shape)))
             if rand:
                 if real:
-                    U, V, S = backend.iddr_asvd(A, k)
+                    U, V, S = _backend.iddr_asvd(A, k)
                 else:
                     if _IS_32BIT:
                         raise _32BIT_ERROR
-                    U, V, S = backend.idzr_asvd(A, k)
+                    U, V, S = _backend.idzr_asvd(A, k)
             else:
                 if real:
-                    U, V, S = backend.iddr_svd(A, k)
+                    U, V, S = _backend.iddr_svd(A, k)
                 else:
-                    U, V, S = backend.idzr_svd(A, k)
+                    U, V, S = _backend.idzr_svd(A, k)
     elif isinstance(A, LinearOperator):
         m, n = A.shape
-        matvec = lambda x: A.matvec(x)
-        matveca = lambda x: A.rmatvec(x)
+        def matvec(x):
+            return A.matvec(x)
+        def matveca(x):
+            return A.rmatvec(x)
         if eps_or_k < 1:
             eps = eps_or_k
             if real:
-                U, V, S = backend.iddp_rsvd(eps, m, n, matveca, matvec)
+                U, V, S = _backend.iddp_rsvd(eps, m, n, matveca, matvec)
             else:
                 if _IS_32BIT:
                     raise _32BIT_ERROR
-                U, V, S = backend.idzp_rsvd(eps, m, n, matveca, matvec)
+                U, V, S = _backend.idzp_rsvd(eps, m, n, matveca, matvec)
         else:
             k = int(eps_or_k)
             if real:
-                U, V, S = backend.iddr_rsvd(m, n, matveca, matvec, k)
+                U, V, S = _backend.iddr_rsvd(m, n, matveca, matvec, k)
             else:
                 if _IS_32BIT:
                     raise _32BIT_ERROR
-                U, V, S = backend.idzr_rsvd(m, n, matveca, matvec, k)
+                U, V, S = _backend.idzr_rsvd(m, n, matveca, matvec, k)
     else:
         raise _TYPE_ERROR
     return U, S, V
@@ -949,8 +971,8 @@ def estimate_rank(A, eps):
 
     ..  This function automatically detects the form of the input parameters and
         passes them to the appropriate backend. For details,
-        see :func:`backend.idd_estrank`, :func:`backend.idd_findrank`,
-        :func:`backend.idz_estrank`, and :func:`backend.idz_findrank`.
+        see :func:`_backend.idd_estrank`, :func:`_backend.idd_findrank`,
+        :func:`_backend.idz_estrank`, and :func:`_backend.idz_findrank`.
 
     Parameters
     ----------
@@ -972,9 +994,9 @@ def estimate_rank(A, eps):
 
     if isinstance(A, np.ndarray):
         if real:
-            rank = backend.idd_estrank(eps, A)
+            rank = _backend.idd_estrank(eps, A)
         else:
-            rank = backend.idz_estrank(eps, A)
+            rank = _backend.idz_estrank(eps, A)
         if rank == 0:
             # special return value for nearly full rank
             rank = min(A.shape)
@@ -983,8 +1005,8 @@ def estimate_rank(A, eps):
         m, n = A.shape
         matveca = A.rmatvec
         if real:
-            return backend.idd_findrank(eps, m, n, matveca)
+            return _backend.idd_findrank(eps, m, n, matveca)
         else:
-            return backend.idz_findrank(eps, m, n, matveca)
+            return _backend.idz_findrank(eps, m, n, matveca)
     else:
         raise _TYPE_ERROR
