@@ -30,6 +30,7 @@
  */
 
 #include "ni_support.h"
+#include "ni_fourier.h"
 #include <stdlib.h>
 #include <math.h>
 #include <assert.h>
@@ -152,33 +153,33 @@ static double _bessel_j1(double x)
     return p * SQ2OPI / sqrt(x);
 }
 
-#define CASE_FOURIER_OUT_RR(_po, _tmp, _type) \
-case t ## _type:                              \
-    *(_type*)_po = _tmp;                        \
+#define CASE_FOURIER_OUT_RR(_TYPE, _type, _po, _tmp) \
+case _TYPE:                                          \
+    *(_type *)_po = _tmp;                            \
     break
 
-#define CASE_FOURIER_OUT_RC(_po, _tmp, _type) \
-case t ## _type:                              \
-    (*(_type*)_po).real = tmp;                  \
-    (*(_type*)_po).imag = 0.0;                  \
+#define CASE_FOURIER_OUT_RC(_TYPE, _type, _po, _tmp) \
+case _TYPE:                                          \
+    ((_type *)_po)->real = tmp;                      \
+    ((_type *)_po)->imag = 0.0;                      \
     break
 
-#define CASE_FOURIER_OUT_CC(_po, _tmp_r, _tmp_i, _type) \
-case t ## _type:                                        \
-    (*(_type*)_po).real = _tmp_r;                         \
-    (*(_type*)_po).imag = _tmp_i;                         \
+#define CASE_FOURIER_OUT_CC(_TYPE, _type, _po, _tmp_r, _tmp_i) \
+case _TYPE:                                                    \
+    ((_type *)_po)->real = _tmp_r;                             \
+    ((_type *)_po)->imag = _tmp_i;                             \
     break
 
-#define CASE_FOURIER_FILTER_RC(_pi, _tmp, _tmp_r, _tmp_i, _type) \
-case t ## _type:                                                 \
-    _tmp_r = (*(_type*)_pi).real * _tmp;                           \
-    _tmp_i = (*(_type*)_pi).imag * _tmp;                           \
-    break;
+#define CASE_FOURIER_FILTER_RC(_TYPE, _type, _pi, _tmp, _tmp_r, _tmp_i) \
+case _TYPE:                                                             \
+    _tmp_r = ((_type *)_pi)->real * _tmp;                               \
+    _tmp_i = ((_type *)_pi)->imag * _tmp;                               \
+    break
 
-#define CASE_FOURIER_FILTER_RR(_pi, _tmp, _type) \
-case t ## _type:                                 \
-    _tmp *= *(_type*)_pi;                          \
-    break;
+#define CASE_FOURIER_FILTER_RR(_TYPE, _type, _pi, _tmp) \
+case _TYPE:                                             \
+    _tmp *= *(_type *)_pi;                              \
+    break
 
 int NI_FourierFilter(PyArrayObject *input, PyArrayObject* parameter_array,
                      npy_intp n, int axis, PyArrayObject* output,
@@ -188,22 +189,21 @@ int NI_FourierFilter(PyArrayObject *input, PyArrayObject* parameter_array,
     char *pi, *po;
     double *parameters = NULL, **params = NULL;
     npy_intp kk, hh, size;
-    Float64 *iparameters = (void *)PyArray_DATA(parameter_array);
-    int ll;
+    npy_double *iparameters = (void *)PyArray_DATA(parameter_array);
     NPY_BEGIN_THREADS_DEF;
 
     /* precalculate the parameters: */
-    parameters = (double*)malloc(input->nd * sizeof(double));
+    parameters = malloc(PyArray_NDIM(input) * sizeof(double));
     if (!parameters) {
         PyErr_NoMemory();
         goto exit;
     }
-    for(kk = 0; kk < input->nd; kk++) {
+    for (kk = 0; kk < PyArray_NDIM(input); kk++) {
         /* along the direction of the real transform we must use the given
              length of that dimensons, unless a complex transform is assumed
              (n < 0): */
         int shape = kk == axis ?
-                        (n < 0 ? input->dimensions[kk] : n) : input->dimensions[kk];
+                (n < 0 ? PyArray_DIM(input, kk) : n) : PyArray_DIM(input, kk);
         switch (filter_type) {
             case _NI_GAUSSIAN:
                 parameters[kk] = *iparameters++ * M_PI / (double)shape;
@@ -216,16 +216,17 @@ int NI_FourierFilter(PyArrayObject *input, PyArrayObject* parameter_array,
         }
     }
     /* allocate memory for tables: */
-    params = (double**) malloc(input->nd * sizeof(double*));
+    params = malloc(PyArray_NDIM(input) * sizeof(double*));
     if (!params) {
         PyErr_NoMemory();
         goto exit;
     }
-    for(kk = 0; kk < input->nd; kk++)
+    for (kk = 0; kk < PyArray_NDIM(input); kk++) {
         params[kk] = NULL;
-    for(kk = 0; kk < input->nd; kk++) {
-        if (input->dimensions[kk] > 1) {
-            params[kk] = (double*)malloc(input->dimensions[kk] * sizeof(double));
+    }
+    for (kk = 0; kk < PyArray_NDIM(input); kk++) {
+        if (PyArray_DIM(input, kk) > 1 || filter_type == _NI_ELLIPSOID) {
+            params[kk] = malloc(PyArray_DIM(input, kk) * sizeof(double));
             if (!params[kk]) {
                 PyErr_NoMemory();
                 goto exit;
@@ -238,22 +239,26 @@ int NI_FourierFilter(PyArrayObject *input, PyArrayObject* parameter_array,
     switch (filter_type) {
         case _NI_GAUSSIAN:
             /* calculate the tables of exponentials: */
-            for (hh = 0; hh < input->nd; hh++) {
+            for (hh = 0; hh < PyArray_NDIM(input); hh++) {
                 if (params[hh]) {
                     if (hh == axis && n >= 0) {
-                        for(kk = 0; kk < input->dimensions[hh]; kk++) {
+                        for (kk = 0; kk < PyArray_DIM(input, hh); kk++) {
                             double tmp = parameters[hh] * kk * kk;
                             params[hh][kk] = fabs(tmp) > 50.0 ? 0.0 : exp(tmp);
                         }
-                    } else {
+                    }
+                    else {
+                        const npy_intp dim = PyArray_DIM(input, hh);
                         int jj = 0;
-                        for(kk = 0; kk < (input->dimensions[hh] + 1) / 2; kk++) {
+                        for (kk = 0; kk < (dim + 1) / 2; kk++) {
                             double tmp = parameters[hh] * kk * kk;
-                            params[hh][jj++] = fabs(tmp) > 50.0 ? 0.0 : exp(tmp);
+                            params[hh][jj++] =
+                                            fabs(tmp) > 50.0 ? 0.0 : exp(tmp);
                         }
-                        for(kk = -(input->dimensions[hh] / 2); kk < 0; kk++) {
+                        for (kk = -(dim / 2); kk < 0; kk++) {
                             double tmp = parameters[hh] * kk * kk;
-                            params[hh][jj++] = fabs(tmp) > 50.0 ? 0.0 : exp(tmp);
+                            params[hh][jj++] =
+                                            fabs(tmp) > 50.0 ? 0.0 : exp(tmp);
                         }
                     }
                 }
@@ -261,52 +266,64 @@ int NI_FourierFilter(PyArrayObject *input, PyArrayObject* parameter_array,
             break;
         case _NI_UNIFORM:
             /* calculate the tables of parameters: */
-            for (hh = 0; hh < input->nd; hh++) {
+            for (hh = 0; hh < PyArray_NDIM(input); hh++) {
                 if (params[hh]) {
                     params[hh][0] = 1.0;
                     if (hh == axis && n >= 0) {
                         double tmp = M_PI * parameters[hh] / n;
-                        for(kk = 1; kk < input->dimensions[hh]; kk++)
+                        for (kk = 1; kk < PyArray_DIM(input, hh); kk++) {
                             params[hh][kk] = tmp > 0.0 ?
-                                                                            sin(tmp * kk) / (tmp * kk) : 0.0;
-                    } else {
-                        double tmp = M_PI * parameters[hh] / input->dimensions[hh];
+                                             sin(tmp * kk) / (tmp * kk) : 0.0;
+                        }
+                    }
+                    else {
+                        const npy_intp dim = PyArray_DIM(input, hh);
+                        double tmp = M_PI * parameters[hh] / dim;
                         int jj = 1;
-                        for(kk = 1; kk < (input->dimensions[hh] + 1) / 2; kk++)
+                        for (kk = 1; kk < (dim + 1) / 2; kk++) {
                             params[hh][jj++] = tmp > 0.0 ?
-                                                                            sin(tmp * kk) / (tmp * kk) : 0.0;
-                        for(kk = -(input->dimensions[hh] / 2); kk < 0; kk++)
+                                            sin(tmp * kk) / (tmp * kk) : 0.0;
+                        }
+                        for (kk = -(dim / 2); kk < 0; kk++) {
                             params[hh][jj++] = tmp > 0.0 ?
-                                                                            sin(tmp * kk) / (tmp * kk) : 0.0;
+                                            sin(tmp * kk) / (tmp * kk) : 0.0;
+                        }
                     }
                 }
             }
             break;
         case _NI_ELLIPSOID:
             /* calculate the tables of parameters: */
-            for (hh = 0; hh < input->nd; hh++) {
+            for (hh = 0; hh < PyArray_NDIM(input); hh++) {
                 if (params[hh]) {
                     params[hh][0] = 1.0;
                     if (hh == axis && n >= 0) {
                         double tmp = M_PI * parameters[hh] / n;
-                        for(kk = 0; kk < input->dimensions[hh]; kk++)
+                        for (kk = 0; kk < PyArray_DIM(input, hh); kk++) {
                             params[hh][kk] = (double)kk * tmp;
-                    } else {
-                        double tmp = M_PI * parameters[hh] / input->dimensions[hh];
-                        int jj = 0;
-                        for(kk = 0; kk < (input->dimensions[hh] + 1) / 2; kk++)
-                            params[hh][jj++] = (double)kk * tmp;
-                        for(kk = -(input->dimensions[hh] / 2); kk < 0; kk++)
-                            params[hh][jj++] = (double)kk * tmp;
+                        }
                     }
-                } else if (input->dimensions[hh] > 0) {
+                    else {
+                        const npy_intp dim = PyArray_DIM(input, hh);
+                        double tmp = M_PI * parameters[hh] / dim;
+                        int jj = 0;
+                        for(kk = 0; kk < (dim + 1) / 2; kk++) {
+                            params[hh][jj++] = (double)kk * tmp;
+                        }
+                        for(kk = -(dim / 2); kk < 0; kk++) {
+                            params[hh][jj++] = (double)kk * tmp;
+                        }
+                    }
+                }
+                else if (PyArray_DIM(input, hh) > 0) {
                     params[hh][0] = 1.0;
                 }
             }
-            if (input->nd > 1)
-                for(hh = 0; hh < input->nd; hh++)
-                    for(kk = 0; kk < input->dimensions[hh]; kk++)
-                        params[hh][kk] = params[hh][kk] * params[hh][kk];
+            if (PyArray_NDIM(input) > 1)
+                for(hh = 0; hh < PyArray_NDIM(input); hh++)
+                    for(kk = 0; kk < PyArray_DIM(input, hh); kk++) {
+                        params[hh][kk] *= params[hh][kk];
+                    }
             break;
         default:
             break;
@@ -319,24 +336,23 @@ int NI_FourierFilter(PyArrayObject *input, PyArrayObject* parameter_array,
         goto exit;
     pi = (void *)PyArray_DATA(input);
     po = (void *)PyArray_DATA(output);
-    size = 1;
-    for(ll = 0; ll < input->nd; ll++)
-        size *= input->dimensions[ll];
+    size = PyArray_SIZE(input);
     /* iterator over the elements: */
     for(hh = 0; hh < size; hh++) {
         double tmp = 1.0;
         switch (filter_type) {
         case _NI_GAUSSIAN:
         case _NI_UNIFORM:
-            for(kk = 0; kk < input->nd; kk++)
+            for (kk = 0; kk < PyArray_NDIM(input); kk++) {
                 if (params[kk])
                     tmp *= params[kk][ii.coordinates[kk]];
+            }
             break;
         case _NI_ELLIPSOID:
-            switch (input->nd) {
+            switch (PyArray_NDIM(input)) {
             case 1:
                 tmp = params[0][ii.coordinates[0]];
-                tmp = tmp > 0.0 ? sin(tmp) / (tmp) : 1.0;
+                tmp = tmp != 0 ? sin(tmp) / (tmp) : 1.0;
                 break;
             case 2:
                 tmp = 0.0;
@@ -364,50 +380,53 @@ int NI_FourierFilter(PyArrayObject *input, PyArrayObject* parameter_array,
         default:
             break;
         }
-        if (NI_NormalizeType(input->descr->type_num) == tComplex64 ||
-                NI_NormalizeType(input->descr->type_num) == tComplex128) {
+        if (PyArray_TYPE(input) == NPY_CFLOAT ||
+                PyArray_TYPE(input) == NPY_CDOUBLE) {
             double tmp_r = 0.0, tmp_i = 0.0;
-            switch (NI_NormalizeType(input->descr->type_num)) {
-                CASE_FOURIER_FILTER_RC(pi, tmp, tmp_r, tmp_i, Complex64);
-                CASE_FOURIER_FILTER_RC(pi, tmp, tmp_r, tmp_i, Complex128);
+            switch (PyArray_TYPE(input)) {
+                CASE_FOURIER_FILTER_RC(NPY_CFLOAT, npy_cfloat,
+                                       pi, tmp, tmp_r, tmp_i);
+                CASE_FOURIER_FILTER_RC(NPY_CDOUBLE, npy_cdouble,
+                                       pi, tmp, tmp_r, tmp_i);
             default:
                 NPY_END_THREADS;
                 PyErr_SetString(PyExc_RuntimeError, "data type not supported");
                 goto exit;
             }
-            switch (NI_NormalizeType(output->descr->type_num)) {
-                CASE_FOURIER_OUT_CC(po, tmp_r, tmp_i, Complex64);
-                CASE_FOURIER_OUT_CC(po, tmp_r, tmp_i, Complex128);
+            switch (PyArray_TYPE(output)) {
+                CASE_FOURIER_OUT_CC(NPY_CFLOAT, npy_cfloat, po, tmp_r, tmp_i);
+                CASE_FOURIER_OUT_CC(NPY_CDOUBLE, npy_cdouble, po, tmp_r, tmp_i);
             default:
                 NPY_END_THREADS;
                 PyErr_SetString(PyExc_RuntimeError, "data type not supported");
                 goto exit;
             }
-        } else {
-            switch (NI_NormalizeType(input->descr->type_num)) {
-                CASE_FOURIER_FILTER_RR(pi, tmp, Bool)
-                CASE_FOURIER_FILTER_RR(pi, tmp, UInt8)
-                CASE_FOURIER_FILTER_RR(pi, tmp, UInt16)
-                CASE_FOURIER_FILTER_RR(pi, tmp, UInt32)
-#if HAS_UINT64
-                CASE_FOURIER_FILTER_RR(pi, tmp, UInt64)
-#endif
-                CASE_FOURIER_FILTER_RR(pi, tmp, Int8)
-                CASE_FOURIER_FILTER_RR(pi, tmp, Int16)
-                CASE_FOURIER_FILTER_RR(pi, tmp, Int32)
-                CASE_FOURIER_FILTER_RR(pi, tmp, Int64)
-                CASE_FOURIER_FILTER_RR(pi, tmp, Float32)
-                CASE_FOURIER_FILTER_RR(pi, tmp, Float64)
+        }
+        else {
+            switch (PyArray_TYPE(input)) {
+                CASE_FOURIER_FILTER_RR(NPY_BOOL, npy_bool, pi, tmp);
+                CASE_FOURIER_FILTER_RR(NPY_UBYTE, npy_ubyte, pi, tmp);
+                CASE_FOURIER_FILTER_RR(NPY_USHORT, npy_ushort, pi, tmp);
+                CASE_FOURIER_FILTER_RR(NPY_UINT, npy_uint, pi, tmp);
+                CASE_FOURIER_FILTER_RR(NPY_ULONG, npy_ulong, pi, tmp);
+                CASE_FOURIER_FILTER_RR(NPY_ULONGLONG, npy_ulonglong, pi, tmp);
+                CASE_FOURIER_FILTER_RR(NPY_BYTE, npy_byte, pi, tmp);
+                CASE_FOURIER_FILTER_RR(NPY_SHORT, npy_short, pi, tmp);
+                CASE_FOURIER_FILTER_RR(NPY_INT, npy_int, pi, tmp);
+                CASE_FOURIER_FILTER_RR(NPY_LONG, npy_long, pi, tmp);
+                CASE_FOURIER_FILTER_RR(NPY_LONGLONG, npy_longlong, pi, tmp);
+                CASE_FOURIER_FILTER_RR(NPY_FLOAT, npy_float, pi, tmp);
+                CASE_FOURIER_FILTER_RR(NPY_DOUBLE, npy_double, pi, tmp);
             default:
                 NPY_END_THREADS;
                 PyErr_SetString(PyExc_RuntimeError, "data type not supported");
                 goto exit;
             }
-            switch (NI_NormalizeType(output->descr->type_num)) {
-                CASE_FOURIER_OUT_RR(po, tmp, Float32);
-                CASE_FOURIER_OUT_RR(po, tmp, Float64);
-                CASE_FOURIER_OUT_RC(po, tmp, Complex64);
-                CASE_FOURIER_OUT_RC(po, tmp, Complex128);
+            switch (PyArray_TYPE(output)) {
+                CASE_FOURIER_OUT_RR(NPY_FLOAT, npy_float, po, tmp);
+                CASE_FOURIER_OUT_RR(NPY_DOUBLE, npy_double, po, tmp);
+                CASE_FOURIER_OUT_RC(NPY_CFLOAT, npy_cfloat, po, tmp);
+                CASE_FOURIER_OUT_RC(NPY_CDOUBLE, npy_cdouble, po, tmp);
             default:
                 NPY_END_THREADS;
                 PyErr_SetString(PyExc_RuntimeError, "data type not supported");
@@ -421,25 +440,26 @@ int NI_FourierFilter(PyArrayObject *input, PyArrayObject* parameter_array,
     NPY_END_THREADS;
     free(parameters);
     if (params) {
-        for(kk = 0; kk < input->nd; kk++)
-            if (params[kk]) free(params[kk]);
+        for (kk = 0; kk < PyArray_NDIM(input); kk++) {
+            free(params[kk]);
+        }
         free(params);
     }
     return PyErr_Occurred() ? 0 : 1;
 }
 
-#define CASE_FOURIER_SHIFT_R(_pi, _tmp, _r, _i, _cost, _sint, _type) \
-case t ## _type:                                                     \
-    _tmp = *(_type*)_pi;                                               \
-    _r = _tmp * _cost;                                                 \
-    _i = _tmp * _sint;                                                 \
-    break;
+#define CASE_FOURIER_SHIFT_R(_TYPE, _type, _pi, _tmp, _r, _i, _cost, _sint) \
+case _TYPE:                                                                 \
+    _tmp = *(_type *)_pi;                                                   \
+    _r = _tmp * _cost;                                                      \
+    _i = _tmp * _sint;                                                      \
+    break
 
-#define CASE_FOURIER_SHIFT_C(_pi, _r, _i, _cost, _sint, _type)     \
-case t ## _type:                                                   \
-    _r = (*(_type*)_pi).real * _cost - (*(_type*)_pi).imag * _sint;  \
-    _i = (*(_type*)_pi).real * _sint + (*(_type*)_pi).imag * _cost;  \
-    break;
+#define CASE_FOURIER_SHIFT_C(_TYPE, _type, _pi, _r, _i, _cost, _sint) \
+case _TYPE:                                                           \
+    _r = ((_type *)_pi)->real * _cost - ((_type *)_pi)->imag * _sint; \
+    _i = ((_type *)_pi)->real * _sint + ((_type *)_pi)->imag * _cost; \
+    break
 
 int NI_FourierShift(PyArrayObject *input, PyArrayObject* shift_array,
             npy_intp n, int axis, PyArrayObject* output)
@@ -448,35 +468,35 @@ int NI_FourierShift(PyArrayObject *input, PyArrayObject* shift_array,
     char *pi, *po;
     double *shifts = NULL, **params = NULL;
     npy_intp kk, hh, size;
-    Float64 *ishifts = (void *)PyArray_DATA(shift_array);
-    int ll;
+    npy_double *ishifts = (void *)PyArray_DATA(shift_array);
     NPY_BEGIN_THREADS_DEF;
 
     /* precalculate the shifts: */
-    shifts = (double*)malloc(input->nd * sizeof(double));
+    shifts = malloc(PyArray_NDIM(input) * sizeof(double));
     if (!shifts) {
         PyErr_NoMemory();
         goto exit;
     }
-    for(kk = 0; kk < input->nd; kk++) {
+    for (kk = 0; kk < PyArray_NDIM(input); kk++) {
         /* along the direction of the real transform we must use the given
              length of that dimensons, unless a complex transform is assumed
              (n < 0): */
         int shape = kk == axis ?
-                        (n < 0 ? input->dimensions[kk] : n) : input->dimensions[kk];
+                (n < 0 ? PyArray_DIM(input, kk) : n) : PyArray_DIM(input, kk);
         shifts[kk] = -2.0 * M_PI * *ishifts++ / (double)shape;
     }
     /* allocate memory for tables: */
-    params = (double**) malloc(input->nd * sizeof(double*));
+    params = malloc(PyArray_NDIM(input) * sizeof(double*));
     if (!params) {
         PyErr_NoMemory();
         goto exit;
     }
-    for(kk = 0; kk < input->nd; kk++)
+    for (kk = 0; kk < PyArray_NDIM(input); kk++) {
         params[kk] = NULL;
-    for(kk = 0; kk < input->nd; kk++) {
-        if (input->dimensions[kk] > 1) {
-            params[kk] = (double*)malloc(input->dimensions[kk] * sizeof(double));
+    }
+    for (kk = 0; kk < PyArray_NDIM(input); kk++) {
+        if (PyArray_DIM(input, kk) > 1) {
+            params[kk] = malloc(PyArray_DIM(input, kk) * sizeof(double));
             if (!params[kk]) {
                 PyErr_NoMemory();
                 goto exit;
@@ -486,17 +506,19 @@ int NI_FourierShift(PyArrayObject *input, PyArrayObject* shift_array,
 
     NPY_BEGIN_THREADS;
 
-    for (hh = 0; hh < input->nd; hh++) {
+    for (hh = 0; hh < PyArray_NDIM(input); hh++) {
         if (params[hh]) {
             if (hh == axis && n >= 0) {
-                for(kk = 0; kk < input->dimensions[hh]; kk++)
+                for (kk = 0; kk < PyArray_DIM(input, hh); kk++) {
                     params[hh][kk] = shifts[hh] * kk;
-            } else {
+                }
+            }
+            else {
                 int jj = 0;
-                for(kk = 0; kk < (input->dimensions[hh] + 1) / 2; kk++) {
+                for (kk = 0; kk < (PyArray_DIM(input, hh) + 1) / 2; kk++) {
                     params[hh][jj++] = shifts[hh] * kk;
                 }
-                for(kk = -(input->dimensions[hh] / 2); kk < 0; kk++) {
+                for (kk = -(PyArray_DIM(input, hh) / 2); kk < 0; kk++) {
                     params[hh][jj++] = shifts[hh] * kk;
                 }
             }
@@ -510,41 +532,55 @@ int NI_FourierShift(PyArrayObject *input, PyArrayObject* shift_array,
         goto exit;
     pi = (void *)PyArray_DATA(input);
     po = (void *)PyArray_DATA(output);
-    size = 1;
-    for(ll = 0; ll < input->nd; ll++)
-        size *= input->dimensions[ll];
+    size = PyArray_SIZE(input);
     /* iterator over the elements: */
     for(hh = 0; hh < size; hh++) {
         double tmp = 0.0, sint, cost, r = 0.0, i = 0.0;
-        for(kk = 0; kk < input->nd; kk++)
+        for (kk = 0; kk < PyArray_NDIM(input); kk++) {
             if (params[kk])
                 tmp += params[kk][ii.coordinates[kk]];
+        }
         sint = sin(tmp);
         cost = cos(tmp);
-        switch (NI_NormalizeType(input->descr->type_num)) {
-            CASE_FOURIER_SHIFT_R(pi, tmp, r, i, cost, sint, Bool)
-            CASE_FOURIER_SHIFT_R(pi, tmp, r, i, cost, sint, UInt8)
-            CASE_FOURIER_SHIFT_R(pi, tmp, r, i, cost, sint, UInt16)
-            CASE_FOURIER_SHIFT_R(pi, tmp, r, i, cost, sint, UInt32)
-#if HAS_UINT64
-            CASE_FOURIER_SHIFT_R(pi, tmp, r, i, cost, sint, UInt64)
-#endif
-            CASE_FOURIER_SHIFT_R(pi, tmp, r, i, cost, sint, Int8)
-            CASE_FOURIER_SHIFT_R(pi, tmp, r, i, cost, sint, Int16)
-            CASE_FOURIER_SHIFT_R(pi, tmp, r, i, cost, sint, Int32)
-            CASE_FOURIER_SHIFT_R(pi, tmp, r, i, cost, sint, Int64)
-            CASE_FOURIER_SHIFT_R(pi, tmp, r, i, cost, sint, Float32)
-            CASE_FOURIER_SHIFT_R(pi, tmp, r, i, cost, sint, Float64)
-            CASE_FOURIER_SHIFT_C(pi, r, i, cost, sint, Complex64)
-            CASE_FOURIER_SHIFT_C(pi, r, i, cost, sint, Complex128)
+        switch (PyArray_TYPE(input)) {
+            CASE_FOURIER_SHIFT_R(NPY_BOOL, npy_bool,
+                                 pi, tmp, r, i, cost, sint);
+            CASE_FOURIER_SHIFT_R(NPY_UBYTE, npy_ubyte,
+                                 pi, tmp, r, i, cost, sint);
+            CASE_FOURIER_SHIFT_R(NPY_USHORT, npy_ushort,
+                                 pi, tmp, r, i, cost, sint);
+            CASE_FOURIER_SHIFT_R(NPY_UINT, npy_uint,
+                                 pi, tmp, r, i, cost, sint);
+            CASE_FOURIER_SHIFT_R(NPY_ULONG, npy_ulong,
+                                 pi, tmp, r, i, cost, sint);
+            CASE_FOURIER_SHIFT_R(NPY_ULONGLONG, npy_ulonglong,
+                                 pi, tmp, r, i, cost, sint);
+            CASE_FOURIER_SHIFT_R(NPY_BYTE, npy_byte,
+                                 pi, tmp, r, i, cost, sint);
+            CASE_FOURIER_SHIFT_R(NPY_SHORT, npy_short,
+                                 pi, tmp, r, i, cost, sint);
+            CASE_FOURIER_SHIFT_R(NPY_INT, npy_int,
+                                 pi, tmp, r, i, cost, sint);
+            CASE_FOURIER_SHIFT_R(NPY_LONG, npy_long,
+                                 pi, tmp, r, i, cost, sint);
+            CASE_FOURIER_SHIFT_R(NPY_LONGLONG, npy_longlong,
+                                 pi, tmp, r, i, cost, sint);
+            CASE_FOURIER_SHIFT_R(NPY_FLOAT, npy_float,
+                                 pi, tmp, r, i, cost, sint);
+            CASE_FOURIER_SHIFT_R(NPY_DOUBLE, npy_double,
+                                 pi, tmp, r, i, cost, sint);
+            CASE_FOURIER_SHIFT_C(NPY_CFLOAT, npy_cfloat,
+                                 pi, r, i, cost, sint);
+            CASE_FOURIER_SHIFT_C(NPY_CDOUBLE, npy_cdouble,
+                                 pi, r, i, cost, sint);
         default:
             NPY_END_THREADS;
             PyErr_SetString(PyExc_RuntimeError, "data type not supported");
             goto exit;
         }
-        switch (NI_NormalizeType(output->descr->type_num)) {
-            CASE_FOURIER_OUT_CC(po, r, i, Complex64);
-            CASE_FOURIER_OUT_CC(po, r, i, Complex128);
+        switch (PyArray_TYPE(output)) {
+            CASE_FOURIER_OUT_CC(NPY_CFLOAT, npy_cfloat, po, r, i);
+            CASE_FOURIER_OUT_CC(NPY_CDOUBLE, npy_cdouble, po, r, i);
         default:
             NPY_END_THREADS;
             PyErr_SetString(PyExc_RuntimeError, "data type not supported");
@@ -557,8 +593,9 @@ int NI_FourierShift(PyArrayObject *input, PyArrayObject* shift_array,
     NPY_END_THREADS;
     free(shifts);
     if (params) {
-        for(kk = 0; kk < input->nd; kk++)
+        for (kk = 0; kk < PyArray_NDIM(input); kk++) {
             free(params[kk]);
+        }
         free(params);
     }
     return PyErr_Occurred() ? 0 : 1;
