@@ -543,7 +543,7 @@ def reflective_transformation(y, lb, ub):
 
 
 def print_header_nonlinear():
-    print("{0:^15}{1:^15}{2:^15}{3:^15}{4:^15}{5:^15}"
+    print("{:^15}{:^15}{:^15}{:^15}{:^15}{:^15}"
           .format("Iteration", "Total nfev", "Cost", "Cost reduction",
                   "Step norm", "Optimality"))
 
@@ -553,20 +553,20 @@ def print_iteration_nonlinear(iteration, nfev, cost, cost_reduction,
     if cost_reduction is None:
         cost_reduction = " " * 15
     else:
-        cost_reduction = "{0:^15.2e}".format(cost_reduction)
+        cost_reduction = f"{cost_reduction:^15.2e}"
 
     if step_norm is None:
         step_norm = " " * 15
     else:
-        step_norm = "{0:^15.2e}".format(step_norm)
+        step_norm = f"{step_norm:^15.2e}"
 
-    print("{0:^15}{1:^15}{2:^15.4e}{3}{4}{5:^15.2e}"
+    print("{:^15}{:^15}{:^15.4e}{}{}{:^15.2e}"
           .format(iteration, nfev, cost, cost_reduction,
                   step_norm, optimality))
 
 
 def print_header_linear():
-    print("{0:^15}{1:^15}{2:^15}{3:^15}{4:^15}"
+    print("{:^15}{:^15}{:^15}{:^15}{:^15}"
           .format("Iteration", "Cost", "Cost reduction", "Step norm",
                   "Optimality"))
 
@@ -576,14 +576,14 @@ def print_iteration_linear(iteration, cost, cost_reduction, step_norm,
     if cost_reduction is None:
         cost_reduction = " " * 15
     else:
-        cost_reduction = "{0:^15.2e}".format(cost_reduction)
+        cost_reduction = f"{cost_reduction:^15.2e}"
 
     if step_norm is None:
         step_norm = " " * 15
     else:
-        step_norm = "{0:^15.2e}".format(step_norm)
+        step_norm = f"{step_norm:^15.2e}"
 
-    print("{0:^15}{1:^15.4e}{2}{3}{4:^15.2e}".format(
+    print("{:^15}{:^15.4e}{}{}{:^15.2e}".format(
         iteration, cost, cost_reduction, step_norm, optimality))
 
 
