@@ -37,13 +37,28 @@ def test_from_square_quat_matrix():
         [3, 0, 0, 4],
         [5, 0, 12, 0],
         [0, 0, 0, 1],
-        [0, 0, 0, -1]
+        [-1, -1, -1, 1],
+        [0, 0, 0, -1],  # Check double cover
+        [-1, -1, -1, -1]  # Check double cover
         ])
     r = Rotation.from_quat(x)
-    expected_quat = x / np.array([[5], [13], [1], [1]])
+    expected_quat = x / np.array([[5], [13], [1], [2], [1], [2]])
     assert_array_almost_equal(r.as_quat(), expected_quat)
 
 
+def test_quat_double_to_canonical_single_cover():
+    x = np.array([
+        [-1, 0, 0, 0],
+        [0, -1, 0, 0],
+        [0, 0, -1, 0],
+        [0, 0, 0, -1],
+        [-1, -1, -1, -1]
+        ])
+    r = Rotation.from_quat(x)
+    expected_quat = np.abs(x) / np.linalg.norm(x, axis=1)[:, None]
+    assert_array_almost_equal(r.as_quat(canonical=True), expected_quat)
+
+
 def test_malformed_1d_from_quat():
     with pytest.raises(ValueError):
         Rotation.from_quat(np.array([1, 2, 3]))
@@ -576,8 +591,16 @@ def test_from_euler_extrinsic_rotation_313():
 
 
 def test_as_euler_asymmetric_axes():
+    # helper function for mean error tests
+    def test_stats(error, mean_max, rms_max):
+        mean = np.mean(error, axis=0)
+        std = np.std(error, axis=0)
+        rms = np.hypot(mean, std)
+        assert np.all(np.abs(mean) < mean_max)
+        assert np.all(rms < rms_max)
+
     rnd = np.random.RandomState(0)
-    n = 10
+    n = 1000
     angles = np.empty((n, 3))
     angles[:, 0] = rnd.uniform(low=-np.pi, high=np.pi, size=(n,))
     angles[:, 1] = rnd.uniform(low=-np.pi / 2, high=np.pi / 2, size=(n,))
@@ -586,32 +609,61 @@ def test_as_euler_asymmetric_axes():
     for seq_tuple in permutations('xyz'):
         # Extrinsic rotations
         seq = ''.join(seq_tuple)
-        assert_allclose(angles, Rotation.from_euler(seq, angles).as_euler(seq))
+        rotation = Rotation.from_euler(seq, angles)
+        angles_quat = rotation.as_euler(seq)
+        angles_mat = rotation._as_euler_from_matrix(seq)
+        assert_allclose(angles, angles_quat, atol=0, rtol=1e-12)
+        assert_allclose(angles, angles_mat, atol=0, rtol=1e-12)
+        test_stats(angles_quat - angles, 1e-15, 1e-14)
+        test_stats(angles_mat - angles, 1e-15, 1e-14)
+
         # Intrinsic rotations
         seq = seq.upper()
-        assert_allclose(angles, Rotation.from_euler(seq, angles).as_euler(seq))
+        rotation = Rotation.from_euler(seq, angles)
+        angles_quat = rotation.as_euler(seq)
+        angles_mat = rotation._as_euler_from_matrix(seq)
+        assert_allclose(angles, angles_quat, atol=0, rtol=1e-12)
+        assert_allclose(angles, angles_mat, atol=0, rtol=1e-12)
+        test_stats(angles_quat - angles, 1e-15, 1e-14)
+        test_stats(angles_mat - angles, 1e-15, 1e-14)
 
 
 def test_as_euler_symmetric_axes():
+    # helper function for mean error tests
+    def test_stats(error, mean_max, rms_max):
+        mean = np.mean(error, axis=0)
+        std = np.std(error, axis=0)
+        rms = np.hypot(mean, std)
+        assert np.all(np.abs(mean) < mean_max)
+        assert np.all(rms < rms_max)
+
     rnd = np.random.RandomState(0)
-    n = 10
+    n = 1000
     angles = np.empty((n, 3))
     angles[:, 0] = rnd.uniform(low=-np.pi, high=np.pi, size=(n,))
     angles[:, 1] = rnd.uniform(low=0, high=np.pi, size=(n,))
     angles[:, 2] = rnd.uniform(low=-np.pi, high=np.pi, size=(n,))
 
-    for axis1 in ['x', 'y', 'z']:
-        for axis2 in ['x', 'y', 'z']:
-            if axis1 == axis2:
-                continue
-            # Extrinsic rotations
-            seq = axis1 + axis2 + axis1
-            assert_allclose(
-                angles, Rotation.from_euler(seq, angles).as_euler(seq))
-            # Intrinsic rotations
-            seq = seq.upper()
-            assert_allclose(
-                angles, Rotation.from_euler(seq, angles).as_euler(seq))
+    for seq_tuple in permutations('xyz'):
+        # Extrinsic rotations
+        seq = ''.join([seq_tuple[0], seq_tuple[1], seq_tuple[0]])
+        rotation = Rotation.from_euler(seq, angles)
+        angles_quat = rotation.as_euler(seq)
+        angles_mat = rotation._as_euler_from_matrix(seq)
+        assert_allclose(angles, angles_quat, atol=0, rtol=1e-13)
+        assert_allclose(angles, angles_mat, atol=0, rtol=1e-9)
+        test_stats(angles_quat - angles, 1e-16, 1e-14)
+        test_stats(angles_mat - angles, 1e-15, 1e-13)
+
+        # Intrinsic rotations
+        seq = seq.upper()
+        rotation = Rotation.from_euler(seq, angles)
+        angles_quat = rotation.as_euler(seq)
+        angles_mat = rotation._as_euler_from_matrix(seq)
+        assert_allclose(angles, angles_quat, atol=0, rtol=1e-13)
+        assert_allclose(angles, angles_mat, atol=0, rtol=1e-9)
+        test_stats(angles_quat - angles, 1e-16, 1e-14)
+        test_stats(angles_mat - angles, 1e-15, 1e-13)
 
 
 def test_as_euler_degenerate_asymmetric_axes():
@@ -621,8 +673,7 @@ def test_as_euler_degenerate_asymmetric_axes():
         [45, 90, 35],
         [35, -90, 20],
         [35, 90, 25],
-        [25, -90, 15]
-        ])
+        [25, -90, 15]])
 
     with pytest.warns(UserWarning, match="Gimbal lock"):
         for seq_tuple in permutations('xyz'):
@@ -658,44 +709,115 @@ def test_as_euler_degenerate_symmetric_axes():
         [15, 0, 60],
         [35, 0, 75],
         [60, 180, 35],
-        [15, -180, 25],
-        ])
+        [15, -180, 25]])
 
     with pytest.warns(UserWarning, match="Gimbal lock"):
-        for axis1 in ['x', 'y', 'z']:
-            for axis2 in ['x', 'y', 'z']:
-                if axis1 == axis2:
-                    continue
+        for seq_tuple in permutations('xyz'):
+            # Extrinsic rotations
+            seq = ''.join([seq_tuple[0], seq_tuple[1], seq_tuple[0]])
+            rotation = Rotation.from_euler(seq, angles, degrees=True)
+            mat_expected = rotation.as_matrix()
 
-                # Extrinsic rotations
-                seq = axis1 + axis2 + axis1
-                rotation = Rotation.from_euler(seq, angles, degrees=True)
-                mat_expected = rotation.as_matrix()
+            angle_estimates = rotation.as_euler(seq, degrees=True)
+            mat_estimated = Rotation.from_euler(
+                seq, angle_estimates, degrees=True
+                ).as_matrix()
 
-                angle_estimates = rotation.as_euler(seq, degrees=True)
-                mat_estimated = Rotation.from_euler(
-                    seq, angle_estimates, degrees=True
-                    ).as_matrix()
+            assert_array_almost_equal(mat_expected, mat_estimated)
 
-                assert_array_almost_equal(mat_expected, mat_estimated)
+            # Intrinsic rotations
+            seq = seq.upper()
+            rotation = Rotation.from_euler(seq, angles, degrees=True)
+            mat_expected = rotation.as_matrix()
 
-                # Intrinsic rotations
-                seq = seq.upper()
-                rotation = Rotation.from_euler(seq, angles, degrees=True)
-                mat_expected = rotation.as_matrix()
+            angle_estimates = rotation.as_euler(seq, degrees=True)
+            mat_estimated = Rotation.from_euler(
+                seq, angle_estimates, degrees=True
+                ).as_matrix()
 
-                angle_estimates = rotation.as_euler(seq, degrees=True)
-                mat_estimated = Rotation.from_euler(
-                    seq, angle_estimates, degrees=True
-                    ).as_matrix()
+            assert_array_almost_equal(mat_expected, mat_estimated)
 
-                assert_array_almost_equal(mat_expected, mat_estimated)
+
+def test_as_euler_degenerate_compare_algorithms():
+    # this test makes sure that both algorithms are doing the same choices
+    # in degenerate cases
+
+    # asymmetric axes
+    angles = np.array([
+        [45, 90, 35],
+        [35, -90, 20],
+        [35, 90, 25],
+        [25, -90, 15]])
+
+    with pytest.warns(UserWarning, match="Gimbal lock"):
+        for seq_tuple in permutations('xyz'):
+            # Extrinsic rotations
+            seq = ''.join(seq_tuple)
+            rot = Rotation.from_euler(seq, angles, degrees=True)
+            estimates_matrix = rot._as_euler_from_matrix(seq, degrees=True)
+            estimates_quat = rot.as_euler(seq, degrees=True)
+            assert_allclose(estimates_matrix[:, [0, 2]],
+                            estimates_quat[:, [0, 2]], atol=0, rtol=1e-12)
+            assert_allclose(estimates_matrix[:, 1], estimates_quat[:, 1],
+                            atol=0, rtol=1e-7)
+
+            # Intrinsic rotations
+            seq = seq.upper()
+            rot = Rotation.from_euler(seq, angles, degrees=True)
+            estimates_matrix = rot._as_euler_from_matrix(seq, degrees=True)
+            estimates_quat = rot.as_euler(seq, degrees=True)
+            assert_allclose(estimates_matrix[:, [0, 2]],
+                            estimates_quat[:, [0, 2]], atol=0, rtol=1e-12)
+            assert_allclose(estimates_matrix[:, 1], estimates_quat[:, 1],
+                            atol=0, rtol=1e-7)
+    # symmetric axes
+    # Absolute error tolerance must be looser to directly compare the results
+    # from both algorithms, because of numerical loss of precision for the
+    # method _as_euler_from_matrix near a zero angle value
+
+    angles = np.array([
+        [15, 0, 60],
+        [35, 0, 75],
+        [60, 180, 35],
+        [15, -180, 25]])
+
+    idx = angles[:, 1] == 0  # find problematic angles indices
+
+    with pytest.warns(UserWarning, match="Gimbal lock"):
+        for seq_tuple in permutations('xyz'):
+            # Extrinsic rotations
+            seq = ''.join([seq_tuple[0], seq_tuple[1], seq_tuple[0]])
+            rot = Rotation.from_euler(seq, angles, degrees=True)
+            estimates_matrix = rot._as_euler_from_matrix(seq, degrees=True)
+            estimates_quat = rot.as_euler(seq, degrees=True)
+            assert_allclose(estimates_matrix[:, [0, 2]],
+                            estimates_quat[:, [0, 2]], atol=0, rtol=1e-12)
+
+            assert_allclose(estimates_matrix[~idx, 1], estimates_quat[~idx, 1],
+                            atol=0, rtol=1e-7)
+
+            assert_allclose(estimates_matrix[idx, 1], estimates_quat[idx, 1],
+                            atol=1e-6)  # problematic, angles[1] = 0
+
+            # Intrinsic rotations
+            seq = seq.upper()
+            rot = Rotation.from_euler(seq, angles, degrees=True)
+            estimates_matrix = rot._as_euler_from_matrix(seq, degrees=True)
+            estimates_quat = rot.as_euler(seq, degrees=True)
+            assert_allclose(estimates_matrix[:, [0, 2]],
+                            estimates_quat[:, [0, 2]], atol=0, rtol=1e-12)
+
+            assert_allclose(estimates_matrix[~idx, 1], estimates_quat[~idx, 1],
+                            atol=0, rtol=1e-7)
+
+            assert_allclose(estimates_matrix[idx, 1], estimates_quat[idx, 1],
+                            atol=1e-6)  # problematic, angles[1] = 0
 
 
 def test_inv():
     rnd = np.random.RandomState(0)
     n = 10
-    p = Rotation.from_quat(rnd.normal(size=(n, 4)))
+    p = Rotation.random(num=n, random_state=rnd)
     q = p.inv()
 
     p_mat = p.as_matrix()
@@ -712,7 +834,7 @@ def test_inv():
 
 def test_inv_single_rotation():
     rnd = np.random.RandomState(0)
-    p = Rotation.from_quat(rnd.normal(size=(4,)))
+    p = Rotation.random(random_state=rnd)
     q = p.inv()
 
     p_mat = p.as_matrix()
@@ -725,7 +847,7 @@ def test_inv_single_rotation():
     assert_array_almost_equal(res1, eye)
     assert_array_almost_equal(res2, eye)
 
-    x = Rotation.from_quat(rnd.normal(size=(1, 4)))
+    x = Rotation.random(num=1, random_state=rnd)
     y = x.inv()
 
     x_matrix = x.as_matrix()
@@ -1040,7 +1162,7 @@ def test_align_vectors_no_rotation():
 
 def test_align_vectors_no_noise():
     rnd = np.random.RandomState(0)
-    c = Rotation.from_quat(rnd.normal(size=4))
+    c = Rotation.random(random_state=rnd)
     b = rnd.normal(size=(5, 3))
     a = c.apply(b)
 
@@ -1078,7 +1200,7 @@ def test_align_vectors_scaled_weights():
 def test_align_vectors_noise():
     rnd = np.random.RandomState(0)
     n_vectors = 100
-    rot = Rotation.from_euler('xyz', rnd.normal(size=3))
+    rot = Rotation.random(random_state=rnd)
     vectors = rnd.normal(size=(n_vectors, 3))
     result = rot.apply(vectors)
 
@@ -1139,6 +1261,10 @@ def test_align_vectors_invalid_input():
                        match="Expected `weights` to have number of values"):
         Rotation.align_vectors([[1, 2, 3]], [[1, 2, 3]], weights=[1, 2])
 
+    with pytest.raises(ValueError,
+                       match="`weights` may not contain negative values"):
+        Rotation.align_vectors([[1, 2, 3]], [[1, 2, 3]], weights=[-1])
+
 
 def test_random_rotation_shape():
     rnd = np.random.RandomState(0)
@@ -1193,12 +1319,28 @@ def test_slerp():
     assert_equal(len(interp_rots), len(times))
 
 
+def test_slerp_rot_is_rotation():
+    with pytest.raises(TypeError, match="must be a `Rotation` instance"):
+        r = np.array([[1,2,3,4],
+                      [0,0,0,1]])
+        t = np.array([0, 1])
+        Slerp(t, r)
+
+
 def test_slerp_single_rot():
-    with pytest.raises(ValueError, match="must be a sequence of rotations"):
+    msg = "must be a sequence of at least 2 rotations"
+    with pytest.raises(ValueError, match=msg):
         r = Rotation.from_quat([1, 2, 3, 4])
         Slerp([1], r)
 
 
+def test_slerp_rot_len1():
+    msg = "must be a sequence of at least 2 rotations"
+    with pytest.raises(ValueError, match=msg):
+        r = Rotation.from_quat([[1, 2, 3, 4]])
+        Slerp([1], r)
+
+
 def test_slerp_time_dim_mismatch():
     with pytest.raises(ValueError,
                        match="times to be specified in a 1 dimensional array"):
@@ -1344,3 +1486,23 @@ def test_concatenate():
 def test_concatenate_wrong_type():
     with pytest.raises(TypeError, match='Rotation objects only'):
         Rotation.concatenate([Rotation.identity(), 1, None])
+
+
+# Regression test for gh-16663
+def test_len_and_bool():
+    rotation_multi_empty = Rotation(np.empty((0, 4)))
+    rotation_multi_one = Rotation([[0, 0, 0, 1]])
+    rotation_multi = Rotation([[0, 0, 0, 1], [0, 0, 0, 1]])
+    rotation_single = Rotation([0, 0, 0, 1])
+
+    assert len(rotation_multi_empty) == 0
+    assert len(rotation_multi_one) == 1
+    assert len(rotation_multi) == 2
+    with pytest.raises(TypeError, match="Single rotation has no len()."):
+        len(rotation_single)
+
+    # Rotation should always be truthy. See gh-16663
+    assert rotation_multi_empty
+    assert rotation_multi_one
+    assert rotation_multi
+    assert rotation_single
