@@ -27,8 +27,8 @@
  * coef[0] = C  , ..., coef[N] = C  .
  *            N                   0
  *
- *  The function p1evl() assumes that coef[N] = 1.0 and is
- * omitted from the array.  Its calling arguments are
+ * The function p1evl() assumes that c_N = 1.0 so that coefficent
+ * is omitted from the array.  Its calling arguments are
  * otherwise the same as polevl().
  *
  *
@@ -41,7 +41,6 @@
  * program in microcode or assembly language.
  *
  */
-
 
 /*
  * Cephes Math Library Release 2.1:  December, 1988
@@ -61,9 +60,9 @@
 #ifndef CEPHES_POLEV
 #define CEPHES_POLEV
 
-#include <numpy/npy_common.h>
+#include <math.h>
 
-static NPY_INLINE double polevl(double x, const double coef[], int N)
+static inline double polevl(double x, const double coef[], int N)
 {
     double ans;
     int i;
@@ -83,10 +82,19 @@ static NPY_INLINE double polevl(double x, const double coef[], int N)
 /*                                                     p1evl() */
 /*                                          N
  * Evaluate polynomial when coefficient of x  is 1.0.
+ * That is, C_{N} is assumed to be 1, and that coefficient
+ * is not included in the input array coef.
+ * coef must have length N and contain the polynomial coefficients
+ * stored as
+ *     coef[0] = C_{N-1}
+ *     coef[1] = C_{N-2}
+ *          ...
+ *     coef[N-2] = C_1
+ *     coef[N-1] = C_0
  * Otherwise same as polevl.
  */
 
-static NPY_INLINE double p1evl(double x, const double coef[], int N)
+static inline double p1evl(double x, const double coef[], int N)
 {
     double ans;
     const double *p;
@@ -105,7 +113,7 @@ static NPY_INLINE double p1evl(double x, const double coef[], int N)
 
 /* Evaluate a rational function. See [1]. */
 
-static NPY_INLINE double ratevl(double x, const double num[], int M,
+static inline double ratevl(double x, const double num[], int M,
                                           const double denom[], int N)
 {
     int i, dir;
