@@ -1,9 +1,9 @@
 
 /* Compute the CDF of the Tukey-Lambda distribution 
- * using a braketing search with special checks
+ * using a bracketing search with special checks
  * 
  * The PPF of the Tukey-lambda distribution is 
- * G(p) = p**lam + (1-p)**lam / lam
+ * G(p) = (p**lam + (1-p)**lam) / lam
  * 
  * Author:  Travis Oliphant 
  */
@@ -26,17 +26,21 @@ double tukeylambdacdf(double x, double lmbda)
 
     xeval = 1.0 / lmbda;
     if (lmbda > 0.0) {
-	if (x < (-xeval))
-	    return 0.0;
-	if (x > xeval)
-	    return 1.0;
+        if (x <= (-xeval)) {
+            return 0.0;
+        }
+        if (x >= xeval) {
+            return 1.0;
+        }
     }
 
     if ((-SMALLVAL < lmbda) && (lmbda < SMALLVAL)) {
-	if (x >= 0)
-	    return 1.0 / (1.0 + exp(-x));
-	else
-	    return exp(x) / (1.0 + exp(x));
+        if (x >= 0) {
+            return 1.0 / (1.0 + exp(-x));
+        }
+        else {
+            return exp(x) / (1.0 + exp(x));
+        }
     }
 
     pmin = 0.0;
@@ -47,18 +51,19 @@ double tukeylambdacdf(double x, double lmbda)
     count = 0;
 
     while ((count < MAXCOUNT) && (fabs(pmid - plow) > EPS)) {
-	xeval = (pow(pmid, lmbda) - pow(1.0 - pmid, lmbda)) / lmbda;
-	if (xeval == x)
-	    return pmid;
-	if (xeval > x) {
-	    phigh = pmid;
-	    pmid = (pmid + plow) / 2.0;
-	}
-	else {
-	    plow = pmid;
-	    pmid = (pmid + phigh) / 2.0;
-	}
-	count++;
+        xeval = (pow(pmid, lmbda) - pow(1.0 - pmid, lmbda)) / lmbda;
+        if (xeval == x) {
+            return pmid;
+        }
+        if (xeval > x) {
+            phigh = pmid;
+            pmid = (pmid + plow) / 2.0;
+        }
+        else {
+            plow = pmid;
+            pmid = (pmid + phigh) / 2.0;
+        }
+        count++;
     }
     return pmid;
 }
