@@ -2,9 +2,10 @@
 #define RCONT_H
 
 #include <numpy/random/distributions.h>
+#include <numpy/npy_common.h>
 #include <stdint.h>
 
-typedef int64_t tab_t;
+typedef npy_int64 tab_t;
 
 void rcont1_init(tab_t *work, int nc, const tab_t *c);
 
