@@ -1,4 +1,3 @@
-
 import pytest
 import numpy as np
 from numpy.testing import assert_allclose
@@ -6,8 +5,7 @@ from scipy.stats import _boost
 
 
 type_char_to_type_tol = {'f': (np.float32, 32*np.finfo(np.float32).eps),
-                         'd': (np.float64, 32*np.finfo(np.float64).eps),
-                         'g': (np.longdouble, 32*np.finfo(np.longdouble).eps)}
+                         'd': (np.float64, 32*np.finfo(np.float64).eps)}
 
 
 # Each item in this list is
@@ -21,6 +19,8 @@ test_data = [
     (_boost._beta_cdf, (0.5, 2, 3), 0.6875),
     (_boost._beta_ppf, (0.6875, 2, 3), 0.5),
     (_boost._beta_pdf, (0.5, 2, 3), 1.5),
+    (_boost._beta_pdf, (0, 1, 5), 5.0),
+    (_boost._beta_pdf, (1, 5, 1), 5.0),
     (_boost._beta_sf, (0.5, 2, 1), 0.75),
     (_boost._beta_isf, (0.75, 2, 1), 0.5),
     (_boost._binom_cdf, (1, 3, 0.5), 0.5),
@@ -31,7 +31,6 @@ test_data = [
 ]
 
 
-@pytest.mark.filterwarnings('ignore::RuntimeWarning')
 @pytest.mark.parametrize('func, args, expected', test_data)
 def test_stats_boost_ufunc(func, args, expected):
     type_sigs = func.types
@@ -39,6 +38,10 @@ def test_stats_boost_ufunc(func, args, expected):
     for type_char in type_chars:
         typ, rtol = type_char_to_type_tol[type_char]
         args = [typ(arg) for arg in args]
-        value = func(*args)
+        # Harmless overflow warnings are a "feature" of some wrappers on some
+        # plaforms. This test is about dtype and accuracy, so let's avoid false
+        # test failures cause by these warnings. See gh-17432.
+        with np.errstate(over='ignore'):
+            value = func(*args)
         assert isinstance(value, typ)
         assert_allclose(value, expected, rtol=rtol)
